@@ -3,7 +3,7 @@ package App::MetaCPANUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-01-01'; # DATE
 our $DIST = 'App-MetaCPANUtils'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -124,6 +124,15 @@ $SPEC{list_recent_metacpan_releases} = {
         },
         %argopt_release_fields,
     },
+    examples => [
+        {
+            summary => 'Show 100 latest releases and show their download URLs',
+            src => '[[prog]] 100 -f download_url',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+    ],
 };
 sub list_recent_metacpan_releases {
     require MetaCPAN::Client;
@@ -146,6 +155,22 @@ $SPEC{list_metacpan_releases} = {
         %argoptf_from_date,
         %argoptf_to_date,
     },
+    examples => [
+        {
+            summary => 'Show releases in December 2020',
+            src => '[[prog]] --from-date 2020-12-01 --to-date 2020-12-31',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+        {
+            summary => "Show PERLANCAR's releases, show only their distribution, version, first (whether the release is the first release for the distribution), and download URL",
+            src => '[[prog]] --author PERLANCAR -f distribution -f version -f first -f download_url',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+    ],
 };
 sub list_metacpan_releases {
     require MetaCPAN::Client;
@@ -192,7 +217,7 @@ App::MetaCPANUtils - CLI utilities related to MetaCPAN
 
 =head1 VERSION
 
-This document describes version 0.002 of App::MetaCPANUtils (from Perl distribution App-MetaCPANUtils), released on 2020-01-01.
+This document describes version 0.003 of App::MetaCPANUtils (from Perl distribution App-MetaCPANUtils), released on 2020-01-01.
 
 =head1 DESCRIPTION
 
